@@ -3,50 +3,43 @@ package PDF::API2::Basic::PDF::Filter::FlateDecode;
 use base 'PDF::API2::Basic::PDF::Filter';
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
-our $VERSION = '2.032'; # VERSION
+our $VERSION = '2.034'; # VERSION
 
 use POSIX qw(ceil floor);
 
 our $havezlib;
 
-BEGIN
-{
+BEGIN {
     eval { require Compress::Zlib };
     $havezlib = !$@;
 }
 
-sub new
-{
+sub new {
     return unless $havezlib;
     my ($class, $decode_parms) = @_;
-    my ($self) = {
-        DecodeParms => $decode_parms,
-    };
+    my $self = { DecodeParms => $decode_parms };
 
     $self->{'outfilt'} = Compress::Zlib::deflateInit(
-      -Level=>9,
-      -Bufsize=>32768,
+        -Level   => 9,
+        -Bufsize => 32768,
     );
     $self->{'infilt'} = Compress::Zlib::inflateInit();
     bless $self, $class;
 }
 
-sub outfilt
-{
-    my ($self, $str, $isend) = @_;
-    my ($res);
+sub outfilt {
+    my ($self, $str, $is_end) = @_;
 
-    $res = $self->{'outfilt'}->deflate($str);
-    $res .= $self->{'outfilt'}->flush() if ($isend);
-    $res;
+    my $result = $self->{'outfilt'}->deflate($str);
+    $result .= $self->{'outfilt'}->flush() if $is_end;
+    return $result;
 }
 
-sub infilt
-{
+sub infilt {
     my ($self, $dat, $last) = @_;
-    my ($res, $status) = $self->{'infilt'}->inflate("$dat");
+    my ($result, $status) = $self->{'infilt'}->inflate("$dat");
 
     if ($self->{'DecodeParms'} and $self->{'DecodeParms'}->{'Predictor'}) {
         my $predictor = $self->{'DecodeParms'}->{'Predictor'}->val();
@@ -54,14 +47,14 @@ sub infilt
             die "The TIFF predictor logic has not been implemented";
         }
         elsif ($predictor >= 10 and $predictor <= 15) {
-            $res = $self->_depredict_png($res);
+            $result = $self->_depredict_png($result);
         }
         else {
             die "Invalid predictor: $predictor";
         }
     }
 
-    return $res;
+    return $result;
 }
 
 sub _depredict_png {
@@ -72,11 +65,11 @@ sub _depredict_png {
     $stream = $self->{'_depredict_next'} . $stream if defined $self->{'_depredict_next'};
     $prev   = $self->{'_depredict_prev'}           if defined $self->{'_depredict_prev'};
 
-    my $alpha   = $param->{Alpha}            ? $param->{Alpha}->val()            : 0;
-    my $bpc     = $param->{BitsPerComponent} ? $param->{BitsPerComponent}->val() : 8;
-    my $colors  = $param->{Colors}           ? $param->{Colors}->val()           : 1;
-    my $columns = $param->{Columns}          ? $param->{Columns}->val()          : 1;
-    my $height  = $param->{Height}           ? $param->{Height}->val()           : 0;
+    my $alpha   = $param->{'Alpha'}            ? $param->{'Alpha'}->val()            : 0;
+    my $bpc     = $param->{'BitsPerComponent'} ? $param->{'BitsPerComponent'}->val() : 8;
+    my $colors  = $param->{'Colors'}           ? $param->{'Colors'}->val()           : 1;
+    my $columns = $param->{'Columns'}          ? $param->{'Columns'}->val()          : 1;
+    my $height  = $param->{'Height'}           ? $param->{'Height'}->val()           : 0;
 
     my $comp     = $colors + $alpha;
     my $bpp      = ceil($bpc * $comp / 8);
@@ -85,12 +78,10 @@ sub _depredict_png {
     my $clearstream = '';
     my $lastrow = ($height || int(length($stream) / $scanline)) - 1;
     foreach my $n (0 .. $lastrow) {
-        # print STDERR "line $n:";
         my $line = substr($stream, $n * $scanline, $scanline);
         my $filter = vec($line, 0, 8);
         my $clear = '';
         $line = substr($line, 1);
-        # print STDERR " filter=$filter ";
         if ($filter == 0) {
             $clear = $line;
         }
@@ -120,9 +111,7 @@ sub _depredict_png {
         $prev = $clear;
         foreach my $x (0 .. ($columns * $comp) - 1) {
             vec($clearstream, ($n * $columns * $comp) + $x, $bpc) = vec($clear, $x, $bpc);
-            # print STDERR "" . vec($clear, $x, $bpc) . ",";
         }
-        # print STDERR "\n";
     }
     $self->{'_depredict_next'} = substr($stream, ($lastrow + 1) * $scanline);
     $self->{'_depredict_prev'} = $prev;
