@@ -5,7 +5,7 @@ use base 'PDF::API2::Basic::PDF::Dict';
 use strict;
 use warnings;
 
-our $VERSION = '2.032'; # VERSION
+our $VERSION = '2.034'; # VERSION
 
 use PDF::API2::Util qw(pdfkey);
 use PDF::API2::Basic::PDF::Utils; # PDFName
@@ -67,14 +67,6 @@ sub name {
     return $self->{'Name'}->val();
 }
 
-sub outobjdeep {
-    my ($self, $fh, $pdf, %options) = @_;
-
-    delete $self->{' api'};
-    delete $self->{' apipdf'};
-    $self->SUPER::outobjdeep($fh, $pdf, %options);
-}
-
 =back
 
 =cut
